==> amazonMap-0.01.zip: amazonMap/blocks/amazon_blocks.php <==
<?php
/**
@brief 
@version $Id$
*/

require_once XOOPS_ROOT_PATH."/modules/exFrame/frameloader.php";

require_once dirname(__FILE__)."/../include/nusoap.php";
require_once dirname(__FILE__)."/../include/cache.php";
require_once dirname(__FILE__)."/../include/amazon.php";
require_once dirname(__FILE__)."/../include/XMLLoader.php";

function b_amzmap_block_show ( $options )
{
	global $xoopsDB;
	$block = array ();

	// ASIN η
	$xoops_root_path = strtr(XOOPS_ROOT_PATH,"\\","/");
	$path= $_SERVER['SCRIPT_FILENAME'];
	if(strpos($path,$xoops_root_path)!==FALSE)
		$path=substr($path,strlen($xoops_root_path));
	
	$loader=new amazonmapXMLLoader();
	$loader->path_=$path;
	$loader->load(dirname(__FILE__)."/../include/mapping.xml");

	$criteria=new CriteriaCompo();
	$criteria->add(new Criteria('path',$path));

	if(count($loader->params_)) {
		foreach($loader->params_ as $param=>$val) {
			if(isset($_REQUEST[$val]))
				$criteria->add(new Criteria($param,intval($_REQUEST[$val])));
		}
	}

	$sql="SELECT * FROM ".$xoopsDB->prefix('amazonmap_mapping')." ".$criteria->renderWhere();
	$res=$xoopsDB->query($sql);
	
	$asins=array();
	while($row=$xoopsDB->fetchArray($res)) {
		$asins[] = $row['asin'];
		unset($row);
	}

	if(!count($asins)) {
		return;
	}

	$cache=&AmazonStructHandler::getInstance();
	$amazon=&AmazonSoapHandler::getInstance();
	
	foreach($asins as $asin) {
		$params['asin']=trim($asin);
		
		if($arr=$cache->build($asin)) {
			$block['items'][]=$arr;
			unset($arr);
		}
		else {
			$arr=$amazon->get($asin);
			if($arr) {
				$block['items'][]=$arr;
				$cache->cache($asin,$arr);
				unset($arr);
			}
		}
	}

	return $block;
}

?>

==> amazonMap-0.03.zip: amazonMap/blocks/amazon_blocks.php <==
<?php
/**
@brief 
@version $Id$
*/

require_once XOOPS_ROOT_PATH."/modules/exFrame/frameloader.php";

require_once dirname(__FILE__)."/../include/nusoap.php";
require_once dirname(__FILE__)."/../include/cache.php";
require_once dirname(__FILE__)."/../include/amazon.php";
require_once dirname(__FILE__)."/../include/XMLLoader.php";

require_once "xoops/perm.php";

function b_amzmap_block_show ( $options )
{
	global $xoopsDB,$xoopsUser;
	$block = array ();

	// ASIN η
	$xoops_root_path = strtr(XOOPS_ROOT_PATH,"\\","/");
	$path= $_SERVER['SCRIPT_FILENAME'];
	if(strpos($path,$xoops_root_path)!==FALSE)
		$path=substr($path,strlen($xoops_root_path));
	
	$loader=new amazonmapXMLLoader();
	$loader->path_=$path;
	$loader->load(dirname(__FILE__)."/../include/mapping.xml");

	$criteria=new CriteriaCompo();
	$criteria->add(new Criteria('path',$path));

	if(count($loader->params_)) {
		foreach($loader->params_ as $param=>$val) {
			if(isset($_REQUEST[$val]))
				$criteria->add(new Criteria($param,intval($_REQUEST[$val])));
		}
	}

	$sql="SELECT * FROM ".$xoopsDB->prefix('amazonmap_mapping')." ".$criteria->renderWhere();
	$res=$xoopsDB->query($sql);
	
	$rows=array();
	while($row=$xoopsDB->fetchArray($res)) {
		$rows[]=$row;
		unset($row);
	}

	if(!count($rows)) {
		return;
	}

	$cache=&AmazonStructHandler::getInstance();
	$amazon=&AmazonSoapHandler::getInstance();
	
	$config=exXoops::getModuleConfigByDirname(exXoops::getDirname(__FILE__));
	$cache->setCacheTime(intval($config['cachetime']));
	
	foreach($rows as $row) {
		$params['asin']= $asin = trim($row['asin']);
		
		if($arr=$cache->build($asin)) {
   			$arr['id']=$row['id'];
			$arr['uid']=$row['uid'];
			$block['items'][]=$arr;
			unset($arr);
		}
		else {
			$arr=$amazon->get($asin);
			if($arr) {
    			$arr['id']=$row['id'];
    			$arr['uid']=$row['uid'];
				$block['items'][]=$arr;
				$cache->cache($asin,$arr);
				unset($arr);
			}
		}
	}
	
	if($block) {
		// 桼
		$block['amzblock_uid']=is_object($xoopsUser) ? $xoopsUser->uid() : 0;
		$block['amzblock_perm']=exPerm::getPermNames(0,exXoops::getMidByDirname(exXoops::getDirname(__FILE__)));
	}

	return $block;
}

?>
